@@ -71,7 +71,7 @@ class Vectorizer(vectorization.Vectorization):
            min_count: int = 0, format_: str = "docterm-matrix", boolean=False) -> Union[Dict[str, dict], Iterable[dict]]:
 
 
-        if not hasattr(self, 'tf_postings'):
+        if not hasattr(self, 'tf_postings') or boolean:
             filters = dict()
             for k, v in self.nlp.config.get_section(s='Vector_filter').items():
                 if v != 'None':
@@ -112,8 +112,15 @@ class Vectorizer(vectorization.Vectorization):
                 if sum(postings[token].values()) < min_count:
                     del postings[token]
 
+            if boolean:
+                if format_ == 'postings-list':
+                    return postings
+                else:
+                    return self.postings2docterm(postings)
+
             self.tf_postings = postings
 
+
         if format_ == 'postings-list':
             return self.tf_postings
         else:
